"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EasyFormPopover = EasyFormPopover;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const real_cancellable_promise_1 = require("real-cancellable-promise");
const hooks_1 = require("../hooks");
const SubmitButton_1 = require("./SubmitButton");
const util_1 = require("../util");
/**
 * Like [[`EasyFormDialog`]], but a popover. For small forms.
 *
 * There must be an empty `div` in the document with ID `easyFormPopoverPortalDestination`.
 */
function EasyFormPopover({ submitButtonText, submitEnabled: propsSubmitEnabled = true, formIsValid, showValidation, onShowValidationChange, onSuccess, focusFirst, onSubmit, onClose, children, }) {
    const submitEnabled = propsSubmitEnabled && (0, iti_react_core_1.getSubmitEnabled)(formIsValid, showValidation);
    const capture = (0, iti_react_core_1.useCancellablePromiseCleanup)();
    const { onError } = (0, react_1.useContext)(iti_react_core_1.ItiReactCoreContext);
    const formRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (focusFirst) {
            // delay it a bit so that popper.js has time to position the popover
            window.setTimeout(() => {
                if (!formRef.current)
                    throw new Error('formRef.current is unexpectedly null.');
                (0, util_1.focusFirstInput)(formRef.current);
            }, 100);
        }
    }, [focusFirst]);
    const [submitting, setSubmitting] = (0, react_1.useState)(false);
    const submittedTimeRef = (0, react_1.useRef)();
    async function submit() {
        var _a;
        if (!submitEnabled)
            return;
        if (submitting)
            return;
        onShowValidationChange(true);
        if (!formIsValid)
            return;
        // Prevent double submit when Ctrl+Enter is pressed in Firefox
        if (submittedTimeRef.current &&
            (0, moment_timezone_1.default)().diff(submittedTimeRef.current, 'ms') < 200) {
            return;
        }
        submittedTimeRef.current = (0, moment_timezone_1.default)();
        setSubmitting(true);
        try {
            // hack to allow onSubmit to return void
            const onSubmitReturnValue = (await onSubmit());
            const shouldClose = (_a = onSubmitReturnValue === null || onSubmitReturnValue === void 0 ? void 0 : onSubmitReturnValue.shouldClose) !== null && _a !== void 0 ? _a : true;
            const responseData = onSubmitReturnValue === null || onSubmitReturnValue === void 0 ? void 0 : onSubmitReturnValue.responseData;
            if (shouldClose) {
                // onSuccess may be loading data, so wait for it to finish before hiding the popover
                // and setting submitting=false
                const promise = onSuccess(responseData);
                try {
                    // To prevent setState after unmount when onSuccess causes the popover to unmount
                    await capture((0, real_cancellable_promise_1.pseudoCancellable)(promise));
                    setSubmitting(false);
                    onClose();
                }
                catch {
                    // popover unmounted - do nothing
                }
            }
            else {
                setSubmitting(false);
            }
        }
        catch (e) {
            onError(e);
        }
    }
    (0, hooks_1.useCtrlEnterListener)(submit, submitEnabled);
    const [portalDestination] = (0, react_1.useState)(() => document.getElementById('easyFormPopoverPortalDestination'));
    if (!portalDestination)
        throw new Error('Could not find easyFormPopoverPortalDestination.');
    return ((0, jsx_runtime_1.jsxs)("form", { onSubmit: (e) => {
            e.preventDefault();
            void submit();
        }, noValidate: true, children: [(0, jsx_runtime_1.jsx)("div", { className: "form-contents", children: children }), (0, jsx_runtime_1.jsx)(SubmitButton_1.SubmitButton, { submitting: submitting, enabled: submitEnabled, className: "btn btn-primary btn-sm", "data-testid": "submit-button", children: submitButtonText })] }));
}
