"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EasyFormPopoverManager = EasyFormPopoverManager;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_popper_1 = require("react-popper");
const react_dom_1 = __importDefault(require("react-dom"));
const event_1 = __importDefault(require("@react-hook/event"));
const hooks_1 = require("../hooks");
/**
 * Like [[`EasyFormDialog`]], but a popover. For small forms.
 *
 * There must be an empty `div` in the document with ID `easyFormPopoverPortalDestination`.
 */
function EasyFormPopoverManager({ renderReferenceElement, children, popoverVisible, onPopoverVisibleChange, }) {
    const [referenceElement, setReferenceElement] = (0, react_1.useState)(null);
    const [popperElement, setPopperElement] = (0, react_1.useState)(null);
    const [arrowElement, setArrowElement] = (0, react_1.useState)(null);
    const { styles, attributes } = (0, react_popper_1.usePopper)(referenceElement, popperElement, {
        modifiers: [
            {
                name: 'offset',
                options: {
                    offset: [0, 9],
                },
            },
            { name: 'arrow', options: { element: arrowElement } },
        ],
    });
    // Close popover on Escape
    (0, event_1.default)(window, 'keydown', (e) => {
        if (popoverVisible && e.code === 'Escape') {
            onPopoverVisibleChange(false);
        }
    });
    (0, hooks_1.usePopoverClickListener)({
        visible: popoverVisible,
        onOutsideClick: () => onPopoverVisibleChange(false),
    });
    const [portalDestination] = (0, react_1.useState)(() => document.getElementById('easyFormPopoverPortalDestination'));
    if (!portalDestination)
        throw new Error('Could not find easyFormPopoverPortalDestination.');
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [renderReferenceElement({
                setRef: setReferenceElement,
                onClick: () => onPopoverVisibleChange(true),
            }), popoverVisible &&
                react_dom_1.default.createPortal((0, jsx_runtime_1.jsxs)("div", { ref: setPopperElement, className: "iti-popover form-popover popover-with-click-listener", style: styles.popper, ...attributes.popper, children: [children, (0, jsx_runtime_1.jsx)("div", { ref: setArrowElement, style: styles.arrow, className: "iti-popover-arrow" })] }), portalDestination)] }));
}
