"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pager = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importDefault(require("react"));
const LinkButton_1 = require("./LinkButton");
// Mark as disabled (rather than making it invisible) so the pager doesn't
// jump around
function PagerLink({ active, onClick, enabled, children }) {
    return ((0, jsx_runtime_1.jsx)("li", { className: `page-item ${active ? 'active' : ''} ${enabled ? '' : 'disabled'}`, children: (0, jsx_runtime_1.jsx)(LinkButton_1.LinkButton, { className: "page-link", tabIndex: enabled ? undefined : -1, onClick: onClick, children: children }) }));
}
/**
 * A simple pagination control that does not allow setting the number of items on a page.
 *
 * These days, [[`ConfigurablePager`]] is generally preferred.
 */
exports.Pager = react_1.default.memo(({ page, totalPages, onPageChange, enabled = true, containerClassName = 'pagination-container', }) => {
    const firstPage = 1;
    const hasPrevious = page !== firstPage;
    const hasNext = page < totalPages;
    // Don't want to show too many pages if there are a lot
    const pagesToDisplay = 5; // odd number
    let pageNumbers = [page];
    let distance = 1;
    // add page number to the left and right until hit the pagesToDisplay
    // and/or run out of pages
    while (true) {
        const left = page - distance;
        const addLeft = left >= firstPage;
        if (addLeft)
            pageNumbers = [left].concat(pageNumbers);
        const right = page + distance;
        const addRight = right <= totalPages;
        if (addRight)
            pageNumbers.push(right);
        if (pageNumbers.length === pagesToDisplay || (!addLeft && !addRight)) {
            break;
        }
        distance += 1;
    }
    return ((0, jsx_runtime_1.jsx)("nav", { "aria-label": "Page navigation", className: containerClassName, children: (0, jsx_runtime_1.jsxs)("ul", { className: "pagination", children: [(0, jsx_runtime_1.jsxs)(PagerLink, { onClick: () => onPageChange(page - 1), enabled: enabled && hasPrevious, children: [(0, jsx_runtime_1.jsx)("span", { "aria-hidden": "true", children: "\u00AB" }), (0, jsx_runtime_1.jsx)("span", { className: "visually-hidden", children: "Previous" })] }, "prev"), pageNumbers.map((i) => ((0, jsx_runtime_1.jsx)(PagerLink, { onClick: () => onPageChange(i), active: page === i, enabled: enabled, children: i }, i.toString()))), (0, jsx_runtime_1.jsxs)(PagerLink, { onClick: () => onPageChange(page + 1), enabled: enabled && hasNext, children: [(0, jsx_runtime_1.jsx)("span", { "aria-hidden": "true", children: "\u00BB" }), (0, jsx_runtime_1.jsx)("span", { className: "visually-hidden", children: "Next" })] }, "next")] }) }));
});
