"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.confirm = confirm;
exports.ConfirmDialog = ConfirmDialog;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_confirm_1 = require("react-confirm");
const lodash_1 = require("lodash");
const dialog_1 = require("./dialog");
const defaultOptions = {
    title: 'Confirm',
};
function ConfirmDialogPresentation({ show, confirmation, loading = false, isStandalone = false, options, closeRef: propsCloseRef, ...otherProps }) {
    const privateCloseRef = (0, react_1.useRef)(() => { });
    const closeRef = propsCloseRef !== null && propsCloseRef !== void 0 ? propsCloseRef : privateCloseRef;
    const proceedCalledRef = (0, react_1.useRef)(false);
    let proceed;
    let onClose;
    if (isStandalone) {
        proceed = otherProps.proceed;
        onClose = () => {
            if (!proceedCalledRef.current)
                otherProps.cancel();
        };
    }
    else {
        proceed = () => {
            proceedCalledRef.current = true;
            closeRef.current();
        };
        onClose = () => {
            if (proceedCalledRef.current) {
                otherProps.proceed();
            }
            else {
                // important: we want to be able to await our confirm function, so call cancel
                // instead of dismiss so that closing the dialog results in the promise being rejected.
                // react-confirm does not resolve or reject if you call dismiss()
                otherProps.cancel();
            }
        };
    }
    const { cancelButtonText, actionButtonText, actionButtonClass, modalClass, title } = (0, lodash_1.defaults)({ ...options }, defaultOptions);
    if (!show)
        return null;
    return ((0, jsx_runtime_1.jsx)(dialog_1.ActionDialog, { title: title, onClose: onClose, closeRef: closeRef, actionButtonText: actionButtonText, actionButtonClass: actionButtonClass, cancelButtonText: cancelButtonText, action: proceed, actionInProgress: loading, focusFirst: true, modalClass: modalClass, children: confirmation }));
}
// confirmable HOC pass props `show`, `dismiss`, `cancel` and `proceed` to your component
const ConfirmableDialog = (0, react_confirm_1.confirmable)(ConfirmDialogPresentation);
const confirm0 = (0, react_confirm_1.createConfirmation)(ConfirmableDialog);
/** Imperative-style confirm dialog backed by `react-confirm`. */
function confirm(confirmation, options) {
    return confirm0({ options, confirmation }).then(() => undefined); // ignore return value
}
/** Standalone confirm dialog that does not use `react-confirm`. */
function ConfirmDialog({ confirmation, proceed, cancel, actionButtonText, actionButtonClass, loading = false, title, cancelButtonText, closeRef, modalClass, }) {
    const options = {
        title,
        actionButtonText,
        actionButtonClass,
        cancelButtonText,
        modalClass,
    };
    return ((0, jsx_runtime_1.jsx)(ConfirmDialogPresentation, { isStandalone: true, confirmation: confirmation, proceed: proceed, cancel: cancel, dismiss: () => {
            throw new Error('ConfirmDialogPresentation called dismiss(). This should never happen!');
        }, show: true, loading: loading, options: options, closeRef: closeRef }));
}
