import React, { PropsWithChildren } from 'react';
import { LinkProps } from 'react-router-dom';
export type TdLinkProps = PropsWithChildren<Omit<LinkProps, 'to'>>;
/**
 * Makes a table cell into a link.
 *
 * It uses a `td-link` class that has styles that are required for it to work
 * correctly.
 *
 * ```
 * <table className="table table-hover table-td-link">
 *     <tbody>
 *         {products.map(p => {
 *             const td = getTdLink('/product/' + p.id)
 *
 *             return (
 *                 <tr key={p.id}>
 *                     {td({ chilrden: p.id })}
 *                     {td({ chilrden: p.name })}
 *                     {td({ chilrden: p.stack })}
 *                 </tr>
 *             )
 *          })}
 *     </tbody>
 * </table>
 * ```
 */
export declare function getTdLink(to: LinkProps['to'], tdProps?: React.HTMLProps<HTMLTableCellElement>): React.FC<TdLinkProps>;
