"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasAncestor = hasAncestor;
exports.hasAncestors = hasAncestors;
exports.usePopoverClickListener = usePopoverClickListener;
const event_1 = __importDefault(require("@react-hook/event"));
const lodash_1 = require("lodash");
const react_1 = require("react");
/** @internal */
function hasAncestor(target, selector) {
    const parent = target.parentElement;
    if (!parent)
        return false;
    if (parent.matches(selector))
        return true;
    return hasAncestor(parent, selector);
}
function hasAncestors(target, selectors) {
    const parent = target.parentElement;
    if (!parent)
        return false;
    if (selectors.some((p) => parent.matches(p)))
        return true;
    return hasAncestors(parent, selectors);
}
/**
 * A hook that detects when the user has clicked outside of a popover,
 * indicating that the popover should be closed.
 */
function usePopoverClickListener({ visible, onOutsideClick, popoverSelector = '.popover-with-click-listener', }) {
    const [visibleSince, setVisibleSince] = (0, react_1.useState)();
    (0, react_1.useEffect)(() => {
        setVisibleSince(visible ? new Date() : undefined);
    }, [visible]);
    function onClick(e) {
        if (!visible)
            return;
        if (!e.target)
            return;
        // The next 3 lines prevent onOutsideClick from firing due to the click
        // event that showed the popover
        if (!visibleSince)
            return;
        const msSinceShown = new Date().valueOf() - visibleSince.valueOf();
        if (msSinceShown < 50)
            return;
        const target = e.target;
        // Hack to prevent clicking a react select option or autocomplete option from closing the popover
        if (hasAncestors(target, ['[class$="-menu"]', '[id$="-autocomplete-list"]']))
            return;
        const inPopover = target.matches(popoverSelector) || hasAncestor(target, popoverSelector);
        if (!inPopover) {
            // To understand why we use defer here, consider what would happen if we
            // did NOT user defer. When the reference element is clicked, onOutsideClick
            // would be called immediately and the popover would be hidden. Then the
            // onClick handler of the reference element would fire, immediately showing
            // the popover again.
            // We used to prevent this using e.stopPropagation(), but stopping
            // propagation causes LinkButton act like a link to # instead of
            // a button.
            (0, lodash_1.defer)(onOutsideClick);
        }
    }
    (0, event_1.default)(document, 'click', onClick);
}
