"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.phoneInputValidator = void 0;
exports.PhoneInput = PhoneInput;
const jsx_runtime_1 = require("react/jsx-runtime");
const input_format_1 = require("input-format");
const react_1 = __importDefault(require("input-format/react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../validation");
const { template, lenWithCountryCode, visibleLen, formatter } = iti_react_core_1.AdvancedPhoneNumberUtil;
const parser = (0, input_format_1.templateParser)(template, input_format_1.parseDigit);
/** Validates a phone number. Automatically used by [[`PhoneInput`]]. */
const phoneInputValidator = (value) => {
    if (value && (0, iti_react_core_1.normalizePhoneNumber)(value).length !== lenWithCountryCode)
        return `The phone number must have exactly ${visibleLen} digits.`;
    return undefined;
};
exports.phoneInputValidator = phoneInputValidator;
/**
 * A validated phone number input. It automatically adds the US/Canada country code (1)
 * to the value. Other country codes are not currently supported.
 *
 * You don't have to pass in a validator that checks that the phone number is valid —
 * this is done automatically. `PhoneInput` can be used with `Validators.required()`.
 */
function PhoneInput({ id, showValidation, enabled = true, name, inputAttributes = {}, ...props }) {
    const { value, onChange: _onChange } = (0, iti_react_core_1.useControlledValue)({
        value: props.value,
        onChange: props.onChange,
        defaultValue: props.defaultValue,
        fallbackValue: '',
    });
    function onChange(newValue) {
        _onChange(newValue ? (0, iti_react_core_1.normalizePhoneNumber)(newValue) : '');
    }
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: props.onValidChange,
        validators: [exports.phoneInputValidator, ...props.validators],
        validationKey: props.validationKey,
        asyncValidator: props.asyncValidator,
        onAsyncError: props.onAsyncError,
        formLevelValidatorOutput: props.formLevelValidatorOutput,
    });
    const normalized = (0, iti_react_core_1.normalizePhoneNumber)(value);
    let noCountryCode = normalized;
    if (normalized.length > 0) {
        noCountryCode = normalized.substring(1);
    }
    return ((0, jsx_runtime_1.jsxs)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: [(0, jsx_runtime_1.jsx)("input", { name: name, value: normalized, type: "hidden" }), (0, jsx_runtime_1.jsx)(react_1.default, { id: id, name: `${name}__display`, disabled: !enabled, onChange: onChange, value: noCountryCode, parse: parser, format: formatter, className: `form-control ${(0, validation_1.getValidationClass)(!validatorOutput, showValidation)}`, ...inputAttributes })] }));
}
