"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateInput = exports.DateValidators = void 0;
exports.convertJsDateToTimeZone = convertJsDateToTimeZone;
exports.parseJsDateIgnoringTimeZone = parseJsDateIgnoringTimeZone;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importStar(require("react"));
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const react_datepicker_1 = __importDefault(require("react-datepicker"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../../validation");
const dateInputUtil_1 = require("./dateInputUtil");
// date-fns format strings (used by react-datepicker)
const fnsDateInputFormat = 'M/d/yyyy';
const fnsTimeFormatWithSeconds = 'h:mm:ss a';
function getDateTimeFormat(includesTime, displaySeconds, isMilitary) {
    if (includesTime) {
        let fnsTimeFormat = fnsTimeFormatWithSeconds;
        if (!displaySeconds)
            fnsTimeFormat = fnsTimeFormat.replace(':ss', '');
        if (isMilitary) {
            fnsTimeFormat = fnsTimeFormat.replace('h', 'HH');
            fnsTimeFormat = fnsTimeFormat.replace(' a', '');
        }
        return `${fnsDateInputFormat} ${fnsTimeFormat}`;
    }
    return fnsDateInputFormat;
}
/**
 * @internal
 */
function convertJsDateToTimeZone(date, timeZone) {
    const str = date.toLocaleString('en-US', { timeZone });
    return new Date(str);
}
/**
 * @internal
 *
 * The offset of `date` must correspond to the browser's time zone for this to work.
 *
 * Example:
 * - assuming DST is in effect
 * - date = 9:00 am, UTC-4 = 1:00 pm UTC
 * - timeZone = America/Los_Angeles
 * - return value = 9:00 am, UTC -7 = 4:00 pm UTC
 */
function parseJsDateIgnoringTimeZone(date, timeZone) {
    const str = date.toLocaleString('en-US');
    return moment_timezone_1.default.tz(str, 'M/D/YYYY, h:mm:ss A', timeZone);
}
//
// Validators
//
function formatValidator(includesTime) {
    return (value) => {
        if (value && !value.isValid())
            return (0, dateInputUtil_1.getInvalidFeedback)(includesTime);
        return undefined;
    };
}
function required(options) {
    return (value) => {
        if (!value)
            return (0, dateInputUtil_1.getInvalidFeedback)(options.includesTime);
        return undefined;
    };
}
/** Validators for use with [[`DateInput`]]. */
exports.DateValidators = {
    required,
};
/**
 * A datetime input with a datepicker popover. See also [[`DateInputNoPicker`]].
 *
 * It is implemented using `react-datepicker`.
 */
exports.DateInput = react_1.default.memo(({ placeholder, includesTime = false, displaySeconds = false, isMilitary = false, popperPlacement, timeIntervals, enabled = true, readOnly = false, filterDate, showValidation, name, className, ...otherProps }) => {
    var _a;
    const timeZone = (0, dateInputUtil_1.getTimeZone)(otherProps.timeZone);
    const idGuidRef = (0, react_1.useRef)((0, iti_react_core_1.getGuid)());
    const id = (_a = otherProps.id) !== null && _a !== void 0 ? _a : idGuidRef.current;
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: otherProps.value,
        onChange: otherProps.onChange,
        defaultValue: otherProps.defaultValue,
        fallbackValue: null,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: otherProps.onValidChange,
        validators: [formatValidator(includesTime), ...otherProps.validators],
        validationKey: otherProps.validationKey,
        asyncValidator: otherProps.asyncValidator,
        onAsyncError: otherProps.onAsyncError,
        formLevelValidatorOutput: otherProps.formLevelValidatorOutput,
    });
    const fnsFormat = getDateTimeFormat(includesTime, displaySeconds, isMilitary);
    function datePickerOnChange(date) {
        const d = date ? parseJsDateIgnoringTimeZone(date, timeZone) : null;
        onChange(d);
    }
    const classes = [
        'form-control',
        (0, validation_1.getValidationClass)(!validatorOutput, showValidation),
    ];
    if (otherProps.inputClassName)
        classes.push(otherProps.inputClassName);
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, className: className, children: (0, jsx_runtime_1.jsx)(react_datepicker_1.default, { id: id, name: name, selected: value ? convertJsDateToTimeZone(value.toDate(), timeZone) : null, onChange: datePickerOnChange, className: classes.join(' '), dateFormat: fnsFormat, placeholderText: placeholder, popperPlacement: popperPlacement, disabledKeyboardNavigation: true, showTimeSelect: includesTime, timeIntervals: timeIntervals, timeFormat: isMilitary ? dateInputUtil_1.militaryTimeFormat : dateInputUtil_1.timeFormat, filterDate: filterDate, disabled: !enabled, readOnly: readOnly, autoComplete: "off" }) }));
});
