import React, { PropsWithChildren } from 'react';
import { ValidatorOutput } from '@interface-technologies/iti-react-core';
/**
 * Used to show a loading indicator when async validation is progress. Uses debouncing
 * so the loading indicator is never displayed if the async validation completes quickly.
 */
export declare function useDebouncedAsyncValidationPending(propsPending: boolean): boolean;
export type ValidationFeedbackProps = PropsWithChildren<{
    validatorOutput: ValidatorOutput;
    showValidation: boolean;
    renderLoadingIndicator?: () => React.ReactNode;
    className?: string;
}>;
/**
 * Displays validation feedback below an input. Used by `ValidatedInput`, .etc.
 *
 * You usually won't use this directly unless creating your own input component.
 */
export declare function ValidationFeedback({ validatorOutput, showValidation, children, renderLoadingIndicator, className, }: ValidationFeedbackProps): JSX.Element;
/**
 * Returns a Bootstrap validation class depending on `valid` and `showValidation`.
 */
export declare function getValidationClass(valid: boolean, showValidation: boolean): string;
